simplify.Event

Package simplify :: Class Event |
[hide private]
[frames] | no frames]

# Class Event

source code

    domain.Domain --+
                    |
                   Event

A Event object.

Instance Methods | [hide private]
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Create an Event object. | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Create an Event object. Parameters: `params` - a dict of parameters; valid keys are: `payload`: The raw JWS message payload. required `url`: The URL for the webhook. If present it must match the URL registered for the webhook. `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: an Event object